pub fn configured_official_schema_plugins(
plugin_ids: &[String],
) -> Result<Vec<AuthPlugin>, RustAuthError>Expand description
Instantiate official schema plugins for the ids configured in rustauth.toml.
pub fn configured_official_schema_plugins(
plugin_ids: &[String],
) -> Result<Vec<AuthPlugin>, RustAuthError>Instantiate official schema plugins for the ids configured in rustauth.toml.