pub fn official_schema_plugin(
plugin_id: &str,
) -> Option<Result<AuthPlugin, RustAuthError>>Expand description
Build a schema-planning plugin instance with official defaults, when the plugin contributes database schema.
pub fn official_schema_plugin(
plugin_id: &str,
) -> Option<Result<AuthPlugin, RustAuthError>>Build a schema-planning plugin instance with official defaults, when the plugin contributes database schema.